macholib.dylib — Generic dylib path manipulation — macholib v1.4.3 documentation

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »

# `macholib.dylib` — Generic dylib path manipulation

This module defines a function `dylib_info()` that can extract useful information from the name of a dynamic library.

`macholib.dylib.` `dylib_info`(filename)

  A dylib name can take one of the following four forms:

  - `Location/Name.SomeVersion_Suffix.dylib`
  - `Location/Name.SomeVersion.dylib`
  - `Location/Name_Suffix.dylib`
  - `Location/Name.dylib`

  Returns None if not found or a mapping equivalent to:

      dict(
          location='Location',
          name='Name.SomeVersion_Suffix.dylib',
          shortname='Name',
          version='SomeVersion',
          suffix='Suffix',
      )

  Note

  SomeVersion and Suffix are optional and my be `None` if not present.

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.3 documentation »